@@ -593,15 +593,20 @@ cmddialog_run (GtkWindow    *gw_parent,
     GtkWidget *gw_array[4];        /* Array with widgets for clicked events */
     char      *s_result = NULL;    /* Result string with wall set command */
     int        i_res    = 0;       /* Config dialog result */
-    Setting   *st_wms;             /* Window manager info list */
-    Setting   *st_crwm;            /* Current window manager info */
+    Setting   *st_wms   = NULL;    /* Window manager info list */
+    Setting   *st_crwm  = NULL;    /* Current window manager info */
     int        i_err    = 0;       /* Error output */
 
-    st_wms = wms_get_wm_info (&i_err);
+    i_err = wms_check_for_new_wms (deffiles_wm_get_buff ());
+
+    if (i_err == ERR_OK) {
+        st_wms = wms_get_wm_info (&i_err);
+    }
 
     if (i_err != ERR_OK) {
         return NULL;
     }
+
     GtkDialogFlags flags = GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT;
 
     gw_dialog = gtk_dialog_new_with_buttons (
