@@ -28,29 +28,6 @@
 #include "hashfun.h"
 #include "setting.h"
 /*----------------------------------------------------------------------------*/
-/**
- * @def    setting_set_type(setting,type)
- * @brief  Set Setting type value
- *
- * @def    setting_set_name(setting,name)
- * @brief  Set Setting name string
- *
- * @def    setting_set_hash(setting,val)
- * @brief  Set Setting hash value
- */
-/*----------------------------------------------------------------------------*/
-#define setting_set_type(setting,type) (setting->v_type = type)
-
-#define setting_set_name(setting,name) (setting->s_name = strdup (name))
-
-#define setting_set_hash(setting,val)  (setting->hash = val)
-/*----------------------------------------------------------------------------*/
-/**
- * @brief  Free string data in Setting
- */
-/*----------------------------------------------------------------------------*/
-#define setting_free_string(setting)   (free (setting->data.s_val))
-/*----------------------------------------------------------------------------*/
 /**
  * @brief  Setting initialization.
  *
@@ -69,6 +46,57 @@ static void setting_init (Setting *st_set);
 static void setting_copy2 (Setting       *st_dest,
                            const Setting *st_src);
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Set Setting type value
+ *
+ * @param[in] st_setting  Setting item
+ * @param[in] val         Type value to set
+ * @return    none
+ */
+static inline void
+setting_set_type (Setting    *st_setting,
+                  SetValType  val)
+{
+    st_setting->v_type = val;
+}
+/*----------------------------------------------------------------------------*/
+/**
+ * @brief  Set Setting name string
+ *
+ * @param[in] st_setting  Setting item
+ * @param[in] val         Name string to set
+ * @return    none
+ */
+static inline void
+setting_set_name (Setting    *st_setting,
+                  const char *val)
+{
+    st_setting->s_name = strdup (val);
+}
+/*----------------------------------------------------------------------------*/
+/**
+ * @brief  Set Setting hash value
+ *
+ * @param[in] st_setting  Setting item
+ * @param[in] val         Hash value to set
+ * @return    none
+ */
+static inline void
+setting_set_hash (Setting       *st_setting,
+                  uint_fast32_t  val)
+{
+    st_setting->hash = val;
+}
+/*----------------------------------------------------------------------------*/
+/**
+ * @brief  Free string data in Setting
+ */
+static inline void
+setting_free_string (Setting *st_setting)
+{
+    free (st_setting->data.s_val);
+}
+/*----------------------------------------------------------------------------*/
 /**
  * @brief  Setting initialization
  */
@@ -85,11 +113,14 @@ setting_init (Setting *st_set)
 }
 /*----------------------------------------------------------------------------*/
 /**
- * @brief  Free Setting object
+ * @brief  Free Setting data
  */
 void
 setting_free (Setting *st_set)
 {
+    if (st_set == NULL)
+        return;
+
     free (st_set->s_name);
 
     if (setting_get_type (st_set) == SET_VAL_STRING) {
@@ -98,6 +129,9 @@ setting_free (Setting *st_set)
     free (st_set);
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Free all settings in given Setting
+ */
 void
 settings_free_all (Setting *st_set)
 {
@@ -170,6 +204,9 @@ setting_get_string (const Setting *st_set)
         return NULL;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Set setting to string type and its content to val.
+ */
 void
 setting_set_string (Setting    *st_set,
                     const char *val)
@@ -179,10 +216,7 @@ setting_set_string (Setting    *st_set,
 
     setting_set_type (st_set, SET_VAL_STRING);
 
-    if (val == NULL)
-        st_set->data.s_val = strdup ("");
-    else
-        st_set->data.s_val = strdup (val);
+    st_set->data.s_val = (val == NULL) ? strdup ("") : strdup (val);
 }
 /*----------------------------------------------------------------------------*/
 /**
@@ -355,7 +389,7 @@ setting_new_string (const char *s_name,
 }
 /*----------------------------------------------------------------------------*/
 /**
- * @brief  Finds and return first item in a Setting list.
+ * @brief  Find and return first item in a Setting list.
  */
 Setting *
 setting_first (Setting *st_settings)
@@ -374,7 +408,7 @@ setting_first (Setting *st_settings)
 }
 /*----------------------------------------------------------------------------*/
 /**
- * @brief  Finds and return last item in a Setting list.
+ * @brief  Find and return last item in a Setting list.
  */
 Setting *
 setting_last (Setting *st_settings)
@@ -535,9 +569,10 @@ setting_set_child (Setting *st_parent,
                    Setting *st_child)
 {
     st_parent->data.st_child = st_child;
-    st_child->parent         = st_parent;
-    st_child->prev           = NULL;
-    st_child->next           = NULL;
+
+    if (st_child != NULL) {
+        st_child->parent = st_parent;
+    }
 }
 /*----------------------------------------------------------------------------*/
 /**
@@ -643,13 +678,41 @@ setting_get_at_pos (Setting      *st_settings,
     return NULL;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Remove Setting from list.
+ */
+void
+setting_remove (Setting *st_setting)
+{
+    Setting *st_item = NULL;
+
+    if (st_setting->prev != NULL) {
+        st_setting->prev->next = st_setting->next;
+    }
+    if (st_setting->next != NULL) {
+        st_setting->next->prev = st_setting->prev;
+    }
+    if (st_setting->parent != NULL) {
+
+        st_item = st_setting->prev == NULL ?
+                  st_setting->next :
+                  setting_first (st_setting);
+
+        setting_set_child (st_setting->parent, st_item);
+    }
+    if ((st_item = setting_get_child (st_setting)) != NULL) {
+        settings_free_all (st_item);
+    }
+    setting_free (st_setting);
+}
+/*----------------------------------------------------------------------------*/
 #ifdef DEBUG
 /*----------------------------------------------------------------------------*/
 /*
  * @brief  Print setting info
  */
 void
-setting_print (const Setting *st_set)
+setting_print (Setting *st_set)
 {
     switch (st_set->v_type) {
         case SET_VAL_INT:
@@ -708,7 +771,7 @@ setting_print (const Setting *st_set)
 }
 /*----------------------------------------------------------------------------*/
 void
-settings_print (const Setting *st_set)
+settings_print (Setting *st_set)
 {
     while (st_set != NULL) {
         setting_print (st_set);
